==> gtkatlantic_0.4.4.orig.tar.gz: gtkatlantic-0.4.4/src/interface.h <==
/*
 *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
 *
 *
 *  Copyright (C) 2002-2010 Rochet Sylvain
 *
 *  gtkatlantic is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#define BORDER 3

/* prototypes of interface.c */

void interface_create_mainwindow();
void interface_create_menubar();
void interface_create_logo();
void interface_create_getgamespage();
void interface_create_gameconfigpage();
void interface_create_gameinitpage();
void interface_create_gameboardpage();
void interface_message_and_chat_float_unfloat();
void interface_create_message(GtkWidget *container);
void interface_unparent_message();
void interface_destroy_message();
void interface_create_chat(GtkWidget *container);
void interface_unparent_chat();
void interface_destroy_chat();
void interface_create_auctionbox();
void interface_create_aboutwin();
void interface_create_config_panel();
void interface_create_nicknamewin();
void interface_create_estates_tree();
void interface_create_helpwin();

void gameclist_title_showgames();
void gameclist_title_showservers();

void interface_create_messagewin(gchar *msg);

void on_board_expose (GtkWidget *widget, GdkEventExpose *event);
void on_playertoken_expose (GtkWidget *widget, GdkEventExpose *event);
void on_playercards_expose (GtkWidget *widget, GdkEventExpose *event);
void on_logo_expose (GtkWidget *widget, GdkEventExpose *event);
void on_theme_preview_expose (GtkWidget *widget, GdkEventExpose *event);
gboolean update_display();
void update_display_theme_preview();
void update_display_logo();
void update_display_game();

==> gtkatlantic_0.5.0.orig.tar.gz: gtkatlantic-0.5.0/src/interface.h <==
/*
 *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
 *
 *
 *  Copyright © 2002-2014 Sylvain Rochet
 *
 *  gtkatlantic is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#define BORDER 3

/* prototypes of interface.c */

void interface_create_mainwindow();
void interface_create_menubar();
void interface_create_logo();
void interface_create_getgamespage();
void interface_create_gameconfigpage();
void interface_create_gameinitpage();
void interface_create_gameboardpage();
void interface_message_and_chat_float_unfloat();
void interface_create_message(GtkWidget *container);
gboolean interface_message_and_chat_scroll_to_the_end(gpointer data);
void interface_unparent_message();
void interface_destroy_message();
void interface_create_chat(GtkWidget *container);
void interface_unparent_chat();
void interface_destroy_chat();
void interface_create_auctionbox();
void interface_create_aboutwin();
void interface_create_config_panel();
void interface_create_nicknamewin();
void interface_create_estates_tree();
void interface_create_helpwin();

void interface_create_messagewin(gchar *msg);

void on_board_draw(GtkWidget *widget, cairo_t *cr, gpointer data);
void on_playertoken_draw(GtkWidget *widget, cairo_t *cr, gpointer data);
void on_playercards_draw(GtkWidget *widget, cairo_t *cr, gpointer data);
void on_logo_draw(GtkWidget *widget, cairo_t *cr, gpointer data);
void update_display();
